@@ -15,6 +15,10 @@ fn default_false() -> bool {
     false
 }
 
+fn default_column_style_by_unit() -> ConfigColumnStyle {
+    ConfigColumnStyle::ByUnit
+}
+
 fn default_column_align_left() -> ConfigColumnAlign {
     ConfigColumnAlign::Left
 }
@@ -39,6 +43,10 @@ fn default_search_logic_and() -> ConfigSearchLogic {
     ConfigSearchLogic::And
 }
 
+fn default_search_case_smart() -> ConfigSearchCase {
+    ConfigSearchCase::Smart
+}
+
 fn default_sort_order_ascending() -> ConfigSortOrder {
     ConfigSortOrder::Ascending
 }
@@ -292,6 +300,7 @@ pub enum ConfigColumnAlign {
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct ConfigColumn {
     pub kind: ConfigColumnKind,
+    #[serde(default = "default_column_style_by_unit")]
     pub style: ConfigColumnStyle,
     #[serde(default = "default_false")]
     pub numeric_search: bool,
@@ -474,6 +483,8 @@ pub struct ConfigSearch {
     pub nonnumeric_search: ConfigSearchKind,
     #[serde(default = "default_search_logic_and")]
     pub logic: ConfigSearchLogic,
+    #[serde(default = "default_search_case_smart")]
+    pub case: ConfigSearchCase,
 }
 
 impl Default for ConfigSearch {
@@ -482,6 +493,7 @@ impl Default for ConfigSearch {
             numeric_search: ConfigSearchKind::Exact,
             nonnumeric_search: ConfigSearchKind::Partial,
             logic: ConfigSearchLogic::And,
+            case: ConfigSearchCase::Smart,
         }
     }
 }
@@ -500,6 +512,13 @@ pub enum ConfigSearchLogic {
     Nor,
 }
 
+#[derive(Clone, Debug, Serialize, Deserialize)]
+pub enum ConfigSearchCase {
+    Smart,
+    Insensitive,
+    Sensitive,
+}
+
 #[derive(Clone, Debug, Serialize, Deserialize)]
 pub struct ConfigDisplay {
     #[serde(default = "default_false")]
